@@ -72,9 +72,12 @@ class SkypeChat(SkypeObj):
         return [SkypeMsg.fromRaw(self.skype, json) for json in resp.get("messages", [])]
 
     def createRaw(self, msg):
+        # All fields except timezone are required; 1418 = desktop client.
+        client = ("os=Windows; osVer=10; proc=x86; lcid=en-US; deviceType=1; country=US; "
+                  "clientName=skype4life; clientVer=1418/9.99.0.999//skype4life")
         resp = self.skype.conn("POST", "{0}/users/ME/conversations/{1}/messages"
                                        .format(self.skype.conn.msgsHost, self.id),
-                               auth=SkypeConnection.Auth.RegToken, json=msg)
+                               auth=SkypeConnection.Auth.RegToken, headers={"ClientInfo": client}, json=msg)
         url = resp.headers.get("Location")
         msgId = url.rsplit("/", 1)[-1] if url else None
         arriveTime = resp.json().get("OriginalArrivalTime")
@@ -338,9 +341,12 @@ class SkypeGroupChat(SkypeChat):
         active (bool):
             Whether the full group chat was retrieved from the server.  This may be ``False`` if a group conversation
             still appears in the recent list despite being left or deleted.
+        moderated (bool):
+            Whether the group chat is a Skype Moderated Group.
     """
 
-    attrs = SkypeChat.attrs + ("topic", "creatorId", "userIds", "adminIds", "open", "history", "picture", "active")
+    attrs = SkypeChat.attrs + ("topic", "creatorId", "userIds", "adminIds", "open", "history", "picture", "active",
+                               "moderated")
 
     @classmethod
     def rawToFields(cls, raw={}, active=False):
@@ -357,6 +363,7 @@ class SkypeGroupChat(SkypeChat):
                        "creatorId": SkypeUtils.noPrefix(props.get("creator")),
                        "userIds": userIds,
                        "adminIds": adminIds,
+                       "moderated": props.get("moderatedthread") == "true",
                        "open": props.get("joiningenabled", "") == "true",
                        "history": props.get("historydisclosed", "") == "true",
                        "picture": props.get("picture", "")[4:] or None,
@@ -381,6 +388,18 @@ class SkypeGroupChat(SkypeChat):
                         auth=SkypeConnection.Auth.RegToken, params={"name": "topic"}, json={"topic": topic})
         self.topic = topic
 
+    def setModerated(self, moderated=True):
+        """
+        Update the chat type, and make chat moderated.
+
+        Args:
+            moderated (bool): whether to enable moderation restrictions
+        """
+        self.skype.conn("PUT", "{0}/threads/{1}/properties".format(self.skype.conn.msgsHost, self.id),
+                        auth=SkypeConnection.Auth.RegToken, params={"name": "moderatedthread"},
+                        json={"moderatedthread": moderated})
+        self.moderated = moderated
+
     def setOpen(self, open):
         """
         Enable or disable joining by URL.  This does not affect current participants inviting others.
@@ -465,12 +484,13 @@ class SkypeChats(SkypeObjs):
         Each conversation is only retrieved once, so subsequent calls will retrieve older conversations.
 
         Returns:
-            :class:`SkypeChat` list: collection of recent conversations
+            :class:`SkypeChat` dict: collection of recent conversations keyed by their ID
         """
         url = "{0}/users/ME/conversations".format(self.skype.conn.msgsHost)
         params = {"startTime": 0,
-                  "view": "msnp24Equivalent",
-                  "targetType": "Passport|Skype|Lync|Thread"}
+                  "view": "supportsExtendedHistory|msnp24Equivalent",
+                  "targetType": "Passport|Skype|Lync|Thread|Agent|ShortCircuit|PSTN|Flxt|NotificationStream|"
+                                "ModernBots|secureThreads|InviteFree"}
         resp = self.skype.conn.syncStateCall("GET", url, params, auth=SkypeConnection.Auth.RegToken).json()
         chats = {}
         for json in resp.get("conversations", []):
@@ -492,7 +512,7 @@ class SkypeChats(SkypeObjs):
                                auth=SkypeConnection.Auth.RegToken, params={"view": "msnp24Equivalent"}).json()
         return self.merge(SkypeChat.fromRaw(self.skype, json))
 
-    def create(self, members=(), admins=()):
+    def create(self, members=(), admins=(), moderated=False):
         """
         Create a new group chat with the given users.
 
@@ -502,17 +522,19 @@ class SkypeChats(SkypeObjs):
         Args:
             members (str list): user identifiers to initially join the conversation
             admins (str list): user identifiers to gain admin privileges
+            moderate (bool): whether to enable moderation restrictions
 
         Returns:
             :class:`SkypeGroupChat`: newly created group conversation
         """
         memberObjs = [{"id": "8:{0}".format(self.skype.userId), "role": "Admin"}]
+        props = {"moderatedthread": moderated}
         for id in members:
             if id == self.skype.userId:
                 continue
             memberObjs.append({"id": "8:{0}".format(id), "role": "Admin" if id in admins else "User"})
         resp = self.skype.conn("POST", "{0}/threads".format(self.skype.conn.msgsHost),
-                               auth=SkypeConnection.Auth.RegToken, json={"members": memberObjs})
+                               auth=SkypeConnection.Auth.RegToken, json={"members": memberObjs, "properties": props})
         return self.chat(resp.headers["Location"].rsplit("/", 1)[1])
 
     @staticmethod
